pub struct Hash(pub [u8; 32]);Expand description
A 32-byte SHA-512/256 hash.
Tuple Fields
0: [u8; 32]Implementations
Sourceimpl Hash
impl Hash
Sourcepub fn digest_bytes(data: &[u8]) -> Hash
pub fn digest_bytes(data: &[u8]) -> Hash
Compute a digest of the passed slice of bytes.
Sourcepub fn digest_bytes_list(data: &[&[u8]]) -> Hash
pub fn digest_bytes_list(data: &[&[u8]]) -> Hash
Compute a digest of the passed slices of bytes.
Sourcepub fn empty_hash() -> Hash
pub fn empty_hash() -> Hash
Hash of an empty string.